@@ -11,7 +11,8 @@ class LastModifiedValidator(Validator):
         return {
             'page.last_modified.not_found': {
                 'title': 'Last-Modified not found.',
-                'description': lambda value: 'Last-Modified was not found on %s.' % value
+                'description': lambda value: 'Last-Modified was not found on %s.' % value,
+                'category': 'HTTP'
             }
         }
 
